@@ -149,7 +149,7 @@ lift.formula <- function(x, data = NULL,
 
   if(length(form$condition) > 0 && any(names(form$condition) != "")) {
     ind <- sum(names(form$condition) != "")
-    tmp <- as.data.frame(form$condition[1:ind])
+    tmp <- as.data.frame(form$condition[1:ind], stringsAsFactors = TRUE)
     liftData <- cbind(liftData, tmp)
   }
   if(!is.factor(liftData$liftClassVar))
@@ -192,7 +192,7 @@ plot.lift <- function(x, y = NULL, ...) xyplot.lift(x = x, data = NULL, ...)
 #' @importFrom grDevices extendrange
 #' @export
 xyplot.lift <- function(x, data = NULL, plot = "gain", values = NULL, ...){
-  if(!(plot %in% c("lift", "gain"))) 
+  if(!(plot %in% c("lift", "gain")))
     stop("`plot`` should be either 'lift' or 'gain'", call. = FALSE)
   if(plot == "gain") {
     lFormula <- "CumEventPct ~ CumTestedPct"
@@ -366,16 +366,16 @@ plotRef <- function(x, y, v, iter = 0) {
   ref_values <- ref_values[!is.na(ref_values$CumTestedPct), ]
   if(nrow(ref_values) > 0) {
     for(i in 1:nrow(ref_values)) {
-      panel.segments(x0 = ref_values$CumTestedPct[i], 
+      panel.segments(x0 = ref_values$CumTestedPct[i],
                      x1 = ref_values$CumTestedPct[i],
-                     y0 = 0, 
-                     y1 = ref_values$CumEventPct[i], 
+                     y0 = 0,
+                     y1 = ref_values$CumEventPct[i],
                      lty = lineStyle$lty, col = lineStyle$col,
                      alpha = lineStyle$alpha, lwd = lineStyle$lwd)
-      panel.segments(x0 = 0, 
+      panel.segments(x0 = 0,
                      x1 = ref_values$CumTestedPct[i],
-                     y0 = ref_values$CumEventPct[i], 
-                     y1 = ref_values$CumEventPct[i], 
+                     y0 = ref_values$CumEventPct[i],
+                     y1 = ref_values$CumEventPct[i],
                      lty = lineStyle$lty, col = lineStyle$col,
                      alpha = lineStyle$alpha, lwd = lineStyle$lwd)
     }
@@ -384,15 +384,15 @@ plotRef <- function(x, y, v, iter = 0) {
 
 
 
-utils::globalVariables(c("CumEventPct", "CumTestedPct", 
+utils::globalVariables(c("CumEventPct", "CumTestedPct",
                          "cuts", "x1", "x2", "y1", "y2"))
 #' @rdname lift
 #' @param mapping,environment  Not used (required for \code{ggplot} consistency).
 #' @method ggplot lift
 #' @export
-ggplot.lift <- function (data = NULL, mapping = NULL, plot = "gain", values = NULL, ..., 
+ggplot.lift <- function (data = NULL, mapping = NULL, plot = "gain", values = NULL, ...,
                  environment = NULL) {
-  if(!(plot %in% c("lift", "gain"))) 
+  if(!(plot %in% c("lift", "gain")))
     stop("`plot`` should be either 'lift' or 'gain'", call. = FALSE)
   names(data$data)[names(data$data) == "liftModelVar"] <- "Model"
   nmod <- length(unique(data$data$Model))
@@ -402,54 +402,54 @@ ggplot.lift <- function (data = NULL, mapping = NULL, plot = "gain", values = NU
     lines3 <- data.frame(x1 = data$pct, x2 = 100, y1 = 100, y2 = 100)
     rng <- extendrange(c(0, 100))
     res <- ggplot(data$data, aes(x = CumTestedPct, y = CumEventPct)) +
-      geom_segment(data = lines1, 
-                   aes(x = x1, y = y1, xend = x2, yend = y2),
-                   alpha = .2, lty = 2) + 
-      geom_segment(data = lines2, 
-                   aes(x = x1, y = y1, xend = x2, yend = y2),
-                   alpha = .2, lty = 2) +   
-      geom_segment(data = lines3, 
+      geom_segment(data = lines1,
                    aes(x = x1, y = y1, xend = x2, yend = y2),
                    alpha = .2, lty = 2) +
-      xlab("% Samples Tested") + ylab("% Samples Found") + 
+      geom_segment(data = lines2,
+                   aes(x = x1, y = y1, xend = x2, yend = y2),
+                   alpha = .2, lty = 2) +
+      geom_segment(data = lines3,
+                   aes(x = x1, y = y1, xend = x2, yend = y2),
+                   alpha = .2, lty = 2) +
+      xlab("% Samples Tested") + ylab("% Samples Found") +
       xlim(rng) + ylim(rng)
     res <- if(nmod == 1)
-      res + geom_line() 
-    else 
-      res + geom_line(aes(col = Model)) 
+      res + geom_line()
+    else
+      res + geom_line(aes(col = Model))
     if(!is.null(values)) {
       ref_values <- ddply(data$data, .(Model), get_ref_point, v = values)
       ref_values <- ref_values[!is.na(ref_values$CumTestedPct),]
       if(nrow(ref_values) > 0) {
         if(nmod > 1) {
-          res <- res + 
-            geom_segment(data = ref_values, 
-                         aes(x = CumTestedPct, y = CumEventPct, 
-                             xend = CumTestedPct, yend = 0, 
-                             color = Model))+ 
-            geom_segment(data = ref_values, 
-                         aes(x = CumTestedPct, y = CumEventPct, 
-                             xend = 0, yend = CumEventPct, 
+          res <- res +
+            geom_segment(data = ref_values,
+                         aes(x = CumTestedPct, y = CumEventPct,
+                             xend = CumTestedPct, yend = 0,
+                             color = Model))+
+            geom_segment(data = ref_values,
+                         aes(x = CumTestedPct, y = CumEventPct,
+                             xend = 0, yend = CumEventPct,
                              color = Model))
         } else {
-          res <- res + 
-            geom_segment(data = ref_values, 
-                         aes(x = CumTestedPct, y = CumEventPct, 
-                             xend = CumTestedPct, yend = 0)) + 
-            geom_segment(data = ref_values, 
-                         aes(x = CumTestedPct, y = CumEventPct, 
-                             xend = 0, yend = CumEventPct))           
+          res <- res +
+            geom_segment(data = ref_values,
+                         aes(x = CumTestedPct, y = CumEventPct,
+                             xend = CumTestedPct, yend = 0)) +
+            geom_segment(data = ref_values,
+                         aes(x = CumTestedPct, y = CumEventPct,
+                             xend = 0, yend = CumEventPct))
         }
       }
     }
   } else {
     data$data <- data$data[!is.na(data$data$lift),]
-    res <- ggplot(data$data, aes(x = cuts, y = lift)) + 
+    res <- ggplot(data$data, aes(x = cuts, y = lift)) +
       xlab("Cut-Off") + ylab("Lift")
     res <- if(nmod == 1)
-      res + geom_line() 
-    else 
-      res + geom_line(aes(col = Model)) 
+      res + geom_line()
+    else
+      res + geom_line(aes(col = Model))
   }
   res
 }
@@ -460,10 +460,10 @@ get_ref_point <- function(dat, v, window = 5) {
   y <- dat$CumEventPct
   erx <- extendrange(x)
   ery <- extendrange(y)
-  
-  res <- data.frame(CumEventPct = v, 
+
+  res <- data.frame(CumEventPct = v,
                     CumTestedPct = NA)
-  
+
   for(i in seq(along = v)) {
     nearest <- which.min((y - v[i])^2)
     index <- max(1, nearest - window):min(length(y), nearest + window)
